@@ -79,7 +79,7 @@
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
 #define HAVE_SYS_SYSCALL_H 1
-/* #undef HAVE_SYS_TIMEB_H */
+#define HAVE_SYS_TIMEB_H 1
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -103,6 +103,7 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
+/* #undef HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -199,7 +200,7 @@
 #define HAVE_PTHREAD_YIELD_ZERO_ARG 1
 #define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
 #define HAVE_PUTENV 1
-/* #undef HAVE_READDIR_R */
+#define HAVE_READDIR_R 1
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -394,7 +395,7 @@
 #define SYSTEM_TYPE "Linux"
 #define MACHINE_TYPE "x86_64"
 #define DEFAULT_MACHINE "x86_64"
-/* #undef HAVE_DTRACE */
+#define HAVE_DTRACE 1
 
 #define SIGNAL_WITH_VIO_CLOSE 1
 
@@ -428,7 +429,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -527,17 +528,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 13
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 5
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.13"
+#define PACKAGE_STRING "MySQL Server 10.6.5"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.13"
-#define VERSION "10.5.13"
+#define PACKAGE_VERSION "10.6.5"
+#define VERSION "10.6.5"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
